import { Serializer } from './xcomponentMessages';
var WebSocketPublisher = /** @class */ (function () {
    function WebSocketPublisher(webSocketWrapper, configuration, privateTopics, sessionData) {
        this.webSocketWrapper = webSocketWrapper;
        this.configuration = configuration;
        this.privateTopics = privateTopics;
        this.sessionData = sessionData;
        this.serializer = new Serializer();
    }
    WebSocketPublisher.prototype.send = function (componentName, stateMachineName, messageType, jsonMessage, visibilityPrivate, specifiedPrivateTopic) {
        if (visibilityPrivate === void 0) { visibilityPrivate = false; }
        var data = this.getDataToSend(componentName, stateMachineName, messageType, jsonMessage, visibilityPrivate, specifiedPrivateTopic);
        var webSocketInput = this.serializer.convertToWebsocketInputFormat(data);
        this.webSocketWrapper.send(webSocketInput);
    };
    WebSocketPublisher.prototype.sendWithStateMachineRef = function (stateMachineRef, messageType, jsonMessage, visibilityPrivate, specifiedPrivateTopic) {
        if (visibilityPrivate === void 0) { visibilityPrivate = false; }
        var data = this.getDataToSendWithStateMachineRef(stateMachineRef, messageType, jsonMessage, visibilityPrivate, specifiedPrivateTopic);
        var webSocketInput = this.serializer.convertToWebsocketInputFormat(data);
        this.webSocketWrapper.send(webSocketInput);
    };
    WebSocketPublisher.prototype.canSend = function (componentName, stateMachineName, messageType) {
        if (this.configuration.containsStateMachine(componentName, stateMachineName)) {
            var componentCode = this.configuration.getComponentCode(componentName);
            var stateMachineCode = this.configuration.getStateMachineCode(componentName, stateMachineName);
            return this.configuration.containsPublisher(componentCode, stateMachineCode, messageType);
        }
        return false;
    };
    WebSocketPublisher.prototype.getDataToSend = function (componentName, stateMachineName, messageType, jsonMessage, visibilityPrivate, specifiedPrivateTopic) {
        if (visibilityPrivate === void 0) { visibilityPrivate = false; }
        var componentCode = this.configuration.getComponentCode(componentName);
        var stateMachineCode = this.configuration.getStateMachineCode(componentName, stateMachineName);
        var headerConfig = this.getHeaderConfig(componentCode, stateMachineCode, messageType, visibilityPrivate, specifiedPrivateTopic);
        var routingKey = this.getRoutingKey(componentCode, stateMachineCode, messageType);
        return {
            RoutingKey: routingKey,
            ComponentCode: componentCode,
            Event: {
                Header: headerConfig,
                JsonMessage: JSON.stringify(jsonMessage)
            }
        };
    };
    WebSocketPublisher.prototype.getHeaderConfig = function (componentCode, stateMachineCode, messageType, visibilityPrivate, specifiedPrivateTopic, stateMachineId, workerId) {
        return {
            WorkerId: workerId,
            StateMachineId: stateMachineId,
            StateMachineCode: stateMachineCode,
            ComponentCode: componentCode,
            EventCode: this.configuration.getPublisherDetails(componentCode, stateMachineCode, messageType).eventCode,
            IncomingEventType: 0,
            MessageType: messageType,
            PublishTopic: !visibilityPrivate
                ? undefined
                : specifiedPrivateTopic
                    ? specifiedPrivateTopic
                    : this.privateTopics.getDefaultPublisherTopic(),
            SessionData: this.sessionData
        };
    };
    WebSocketPublisher.prototype.getRoutingKey = function (componentCode, stateMachineCode, messageType) {
        var publisher = this.configuration.getPublisherDetails(componentCode, stateMachineCode, messageType);
        return publisher.routingKey;
    };
    WebSocketPublisher.prototype.getDataToSendWithStateMachineRef = function (stateMachineRef, messageType, jsonMessage, visibilityPrivate, specifiedPrivateTopic) {
        if (visibilityPrivate === void 0) { visibilityPrivate = false; }
        var componentCode = stateMachineRef.ComponentCode;
        var stateMachineCode = stateMachineRef.StateMachineCode;
        var headerConfig = this.getHeaderConfig(componentCode, stateMachineCode, messageType, visibilityPrivate, specifiedPrivateTopic, stateMachineRef.StateMachineId, stateMachineRef.WorkerId);
        var routingKey = this.getRoutingKey(componentCode, stateMachineCode, messageType);
        return {
            RoutingKey: routingKey,
            ComponentCode: componentCode,
            Event: {
                Header: headerConfig,
                JsonMessage: JSON.stringify(jsonMessage)
            }
        };
    };
    return WebSocketPublisher;
}());
export { WebSocketPublisher };
//# sourceMappingURL=WebSocketPublisher.js.map