import { mock, when, anyString, anyNumber, instance } from 'ts-mockito/lib/ts-mockito';
import { DefaultApiConfiguration } from '../configuration/apiConfiguration';
// Initialisation
var componentCode = -69981087;
var stateMachineCode = -829536631;
var eventCode = 9;
var messageType = 'XComponent.HelloWorld.UserObject.SayHello';
var routingKey = 'input.1_0.HelloWorldMicroservice.HelloWorld.HelloWorldManager';
var guiExample = 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx';
var sessionData = 'sessiondata';
function getHeader(visibility) {
    var header = {
        StateMachineCode: stateMachineCode,
        ComponentCode: componentCode,
        EventCode: eventCode,
        IncomingEventType: 0,
        MessageType: messageType,
        PublishTopic: !visibility ? undefined : guiExample,
        SessionData: sessionData
    };
    return header;
}
var jsonMessage = { Name: 'MY NAME' };
function getCorrectData(visibility) {
    return {
        event: {
            Header: getHeader(visibility),
            JsonMessage: JSON.stringify(jsonMessage)
        },
        routingKey: routingKey
    };
}
function getCorretWebsocketInputFormat(visibility) {
    var correctData = getCorrectData(visibility);
    var correctWebsocketInputFormat = correctData.routingKey + ' ' + correctData.event.Header.ComponentCode + ' ' + JSON.stringify(correctData.event);
    return correctWebsocketInputFormat;
}
var stateMachineRef = {
    StateMachineId: '1',
    StateMachineCode: stateMachineCode,
    ComponentCode: componentCode
};
var correctDataForSMRef = {
    event: {
        Header: {
            StateMachineId: stateMachineRef.StateMachineId,
            StateMachineCode: stateMachineRef.StateMachineCode,
            ComponentCode: stateMachineRef.ComponentCode,
            EventCode: eventCode,
            IncomingEventType: 0,
            MessageType: messageType,
            SessionData: sessionData
        },
        JsonMessage: JSON.stringify(jsonMessage)
    },
    routingKey: routingKey
};
var corretWebsocketInputFormatForSendSMRef = correctDataForSMRef.routingKey +
    ' ' +
    correctDataForSMRef.event.Header.ComponentCode +
    ' ' +
    JSON.stringify(correctDataForSMRef.event);
var apiConfiguration = mock(DefaultApiConfiguration);
when(apiConfiguration.getComponentCode(anyString())).thenCall(function (componentName) {
    if (!componentName) {
        throw new Error();
    }
    return componentCode;
});
when(apiConfiguration.getStateMachineCode(anyString(), anyString())).thenCall(function (componentName, stateMachineName) {
    if (!componentName || !stateMachineName) {
        throw new Error();
    }
    return stateMachineCode;
});
when(apiConfiguration.getPublisherDetails(anyNumber(), anyNumber(), anyString())).thenCall(function () {
    return {
        eventCode: eventCode,
        routingKey: routingKey
    };
});
when(apiConfiguration.containsStateMachine(anyString(), anyString())).thenCall(function (componentName, stateMachineName) {
    if (!componentName || !stateMachineName) {
        return false;
    }
    else {
        return true;
    }
});
when(apiConfiguration.containsPublisher(anyNumber(), anyNumber(), anyString())).thenCall(function (compCode, stmCode) {
    return compCode === componentCode && stmCode === stateMachineCode;
});
var returnObject = {
    configuration: instance(apiConfiguration),
    jsonMessage: jsonMessage,
    messageType: messageType,
    correctData: getCorrectData(false),
    getCorretWebsocketInputFormat: getCorretWebsocketInputFormat,
    stateMachineRef: stateMachineRef,
    corretWebsocketInputFormatForSendSMRef: corretWebsocketInputFormatForSendSMRef,
    guiExample: guiExample,
    sessionData: sessionData
};
export default returnObject;
//# sourceMappingURL=mockPublisherDependencies.js.map